package com.mc.monkeynes.gui;

import com.mc.monkeynes.hardware.*;

import java.awt.*;

public class PatternTableView extends Component
{
  private int[]              patternTable = null;
  private PatternTableTile[] tiles        = new PatternTableTile[512];

  public PatternTableView( NesVideoMemory inVidMemory )
  {
    patternTable = inVidMemory.read( 0x00000000, 0x00001FFF );
    buildTiles();
  }
  
  private void buildTiles()
  {
    int[] top = null;
    int[] bot = null;
    
    int x = 0;
    for( int i = 0; i < patternTable.length; i+=16 )
    {
      top = new int[8];
      bot = new int[8];
      
      for( int j = 0; j < 8; j++ )
      {
        top[j] = patternTable[i + j];
        bot[j] = patternTable[i + j + 8];
      }  
      
      tiles[x] = new PatternTableTile( top, bot );
      x++;
    }
  }
  
  public void paint( Graphics g )
  {
    // loop across the tiles
    for( int i = 0; i < 16; i++ )
    {
      for( int j = 0; j < 32; j++ )
      { 
      
        // for each tile, loop across the pixels
        for( int x = 0; x < 8; x++ )
        {
          for( int y = 0; y < 8; y++ )
          { 
            switch( tiles[(j * 16) + i].getPixelValue( x, y ) )
            {
              case 0:
                g.setColor( Color.CYAN );
                break;
              case 1:
                g.setColor( Color.DARK_GRAY );
                break;  
              case 2:
                g.setColor( Color.LIGHT_GRAY );
                break;    
              case 3:
                g.setColor( Color.WHITE );
                break;    
            }
            g.drawRect( (i * 8) + x, (j * 8) + y, 1, 1 );
          }
        }
        
      }
    }  
  }
}