package com.mc.monkeynes.hardware;

import com.mc.monkeynes.base.*;

public class InesRomHeader
{
  private byte[] romHead = null;
  
  private static final int RH_PRG_ROM_COUNT     = 0x00000004;
  private static final int RH_CHR_ROM_COUNT     = 0x00000005;
  private static final int RH_ROM_CONTROL_1     = 0x00000006;
  private static final int RH_ROM_CONTROL_2     = 0x00000007;
  
  
  public static final int PRG_PAGE_SIZE         = 0x00004000;  // 16k
  public static final int CHR_PAGE_SIZE         = 0x00002000;  // 8k
    
  public InesRomHeader( byte[] inRomHeader )
  {
    setRomHeader( inRomHeader );
  }
  
  public void setRomHeader( byte[] inRomHeader )
  {
    romHead = inRomHeader;
  }
  
  public int getPrgRomPageCount()
  {
    return (int)romHead[RH_PRG_ROM_COUNT];
  } 
  
  public int getPrgRomSize()
  {
    return (int)romHead[RH_PRG_ROM_COUNT] * PRG_PAGE_SIZE;
  }   

  public int getChrRomPageCount()
  {
    return (int)romHead[RH_CHR_ROM_COUNT];
  }
  
  public int getChrRomSize()
  {
    return (int)romHead[RH_CHR_ROM_COUNT] * CHR_PAGE_SIZE;
  }  
  
  public int getMapperNumber()
  {
    // shift the correct nibbles into place
    return (((int)romHead[RH_ROM_CONTROL_2]) & MathHelper.nibbleMask[1]) | 
           ((((int)romHead[RH_ROM_CONTROL_1]) & MathHelper.nibbleMask[1]) >> 4 );
  }
  
  public boolean isFourScreenVram()
  {
    return ( romHead[RH_ROM_CONTROL_1] & MathHelper.bitMask[3] ) == MathHelper.bitMask[3];
  }
  
  public boolean isTrainerPresent()
  {
    return ( romHead[RH_ROM_CONTROL_1] & MathHelper.bitMask[2] ) == MathHelper.bitMask[2];
  }
  
  public boolean isSramEnabled()
  {
    return ( romHead[RH_ROM_CONTROL_1] & MathHelper.bitMask[1] ) == MathHelper.bitMask[1];
  }    
  
  public boolean isVertMirror()
  {
    return ( romHead[RH_ROM_CONTROL_1] & MathHelper.bitMask[0] ) == MathHelper.bitMask[0];
  }  
  
  public boolean isHorzMirror()
  {
    return ( romHead[RH_ROM_CONTROL_1] & MathHelper.bitMask[0] ) == 0;
  }   
  
}